#!/usr/bin/env groovy
/*
* Licensed Materials - Property of IBM Corp.
* IBM AnthillPro
* (c) Copyright IBM Corporation 2011, 2013. All Rights Reserved.
*
* U.S. Government Users Restricted Rights - Use, duplication or disclosure restricted by
* GSA ADP Schedule Contract with IBM Corp.
*/


//------------------------------------------------------------------------------
// Utility methods and classes
//------------------------------------------------------------------------------
final def isWindows = (System.getProperty('os.name') =~ /(?i)windows/).find()
final def ahptool = isWindows ? 'ahptool.cmd' : 'ahptool'

final def getStepProperties = {
  def props = [:]

  def ahptoolProc = [ahptool, "getStepProperties"].execute()
  ahptoolProc.consumeProcessErrorStream(System.out);
  def propertiesXml = ahptoolProc.text
  ahptoolProc.waitFor()
  if (ahptoolProc.exitValue()) {
      throw new Exception("Failed to get step properties from ahptool: " + propertiesXml)
  }
  new XmlSlurper().parseText(propertiesXml).property.each{ propElem ->
      props[propElem.@name.text()] = propElem.text()
  }

  return props;
}

//------------------------------------------------------------------------------
// Load plugin jars
//------------------------------------------------------------------------------

final File resourceHome = new File(System.getenv()['PLUGIN_HOME'])
resourceHome.eachFileMatch(~/.*\.jar/){jar ->
   this.class.classLoader.rootLoader.addURL(jar.toURL())
}

//------------------------------------------------------------------------------
// Twitter Integration
//------------------------------------------------------------------------------



def url = "https://twitter.com/statuses/update.json"
final def props = getStepProperties()
final def message = props['message']
final def userName = props['integration/userName']
final def password = props['integration/twitterPassword']

println("Logging in as: " + userName)

def params = Class.forName('org.apache.http.params.BasicHttpParams').newInstance()
params.setParameter("status", message)
def client = Class.forName('org.apache.http.impl.client.DefaultHttpClient').newInstance(params)
def postMethod = Class.forName('org.apache.http.client.methods.HttpPost').newInstance(url)
def anyAuthScope = Class.forName('org.apache.http.auth.AuthScope').ANY 
def credentials = Class.forName('org.apache.http.auth.UsernamePasswordCredentials').newInstance(userName, password)
def credProvider = client.getCredentialsProvider()
credProvider.setCredentials(anyAuthScope, credentials)
client.setCredentialsProvider(credProvider)

def response = client.execute(postMethod)
def statusLine = response.getStatusLine()
int responseCode = statusLine.getStatusCode()
String reason = statusLine.getReasonPhrase()
String content = respose.entity.content.text

if (responseCode >= 200 && responseCode < 300) {
    println("STATUS: " + responseCode + " - " + reason)
    System.out << content
}
else {
    println("STATUS: " + responseCode + " - " + reason + "\nCONTENT:" + content);
    System.exit(1)
}
